@@ -6,107 +6,126 @@
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <location filename="../mainwindow.cpp" line="302"/>
+        <location filename="../ui_mainwindow.h" line="225"/>
         <source>MX Service Manager</source>
         <translation>Менеджер служб MX</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="62"/>
-        <source>About this application</source>
-        <translation>Об этом приложении</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="26"/>
         <location filename="../mainwindow.cpp" line="157"/>
         <location filename="../mainwindow.cpp" line="317"/>
+        <location filename="../ui_mainwindow.h" line="226"/>
         <source>&amp;Enable at boot</source>
         <translation>&amp;Включить при загрузке</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="62"/>
+        <location filename="../ui_mainwindow.h" line="228"/>
+        <source>About this application</source>
+        <translation>Об этом приложении</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="65"/>
+        <location filename="../ui_mainwindow.h" line="230"/>
         <source>&amp;About...</source>
         <translation>&amp;О программе…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="72"/>
+        <location filename="../ui_mainwindow.h" line="232"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="126"/>
+        <location filename="../ui_mainwindow.h" line="236"/>
         <source>Display help </source>
         <translation>Показать справку</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="129"/>
+        <location filename="../ui_mainwindow.h" line="238"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="136"/>
+        <location filename="../ui_mainwindow.h" line="240"/>
+        <source>Alt+H</source>
+        <translation>Alt+H</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="168"/>
+        <location filename="../ui_mainwindow.h" line="243"/>
+        <source>Quit application</source>
+        <translation>Выйти из приложения</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="171"/>
+        <location filename="../ui_mainwindow.h" line="245"/>
         <source>&amp;Close</source>
         <translation>&amp;Закрыть</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="227"/>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <source>Services enabled at boot</source>
-        <translation>Службы включены при загрузке</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="232"/>
-        <location filename="../mainwindow.cpp" line="279"/>
-        <source>Services disabled at boot</source>
-        <translation>Службы отключены при загрузке</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="268"/>
-        <source>search</source>
-        <translation>поиск</translation>
+        <location filename="../mainwindow.ui" line="178"/>
+        <location filename="../ui_mainwindow.h" line="247"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="203"/>
         <location filename="../mainwindow.cpp" line="139"/>
+        <location filename="../ui_mainwindow.h" line="250"/>
         <source>&amp;Stop</source>
         <translation>&amp;Стоп</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="297"/>
-        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
-        <translation>Этот инструмент перечисляет службы и демоны (процессы, работающие в фоновом режиме), найденные на этой системе. Будьте осторожны, чтобы не остановить что-то, что может нарушить работу критического компонента; лучше оставить его в покое, если вы не знаете, что это такое.</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="217"/>
+        <location filename="../ui_mainwindow.h" line="251"/>
         <source>All services</source>
         <translation>Все службы</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="222"/>
         <location filename="../mainwindow.cpp" line="277"/>
+        <location filename="../ui_mainwindow.h" line="252"/>
         <source>Running services</source>
         <translation>Запущенные службы</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="136"/>
-        <source>Alt+H</source>
-        <translation>Alt+H</translation>
+        <location filename="../mainwindow.ui" line="227"/>
+        <location filename="../mainwindow.cpp" line="278"/>
+        <location filename="../ui_mainwindow.h" line="253"/>
+        <source>Services enabled at boot</source>
+        <translation>Службы включены при загрузке</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="168"/>
-        <source>Quit application</source>
-        <translation>Выйти из приложения</translation>
+        <location filename="../mainwindow.ui" line="232"/>
+        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../ui_mainwindow.h" line="254"/>
+        <source>Services disabled at boot</source>
+        <translation>Службы отключены при загрузке</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="178"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
+        <location filename="../mainwindow.ui" line="268"/>
+        <location filename="../ui_mainwindow.h" line="257"/>
+        <source>search</source>
+        <translation>поиск</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="278"/>
         <location filename="../mainwindow.cpp" line="68"/>
         <location filename="../mainwindow.cpp" line="81"/>
+        <location filename="../ui_mainwindow.h" line="258"/>
         <source>Loading...</source>
         <translation>Загрузка...</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="297"/>
+        <location filename="../ui_mainwindow.h" line="259"/>
+        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
+        <translation>Этот инструмент перечисляет службы и демоны (процессы, работающие в фоновом режиме), найденные на этой системе. Будьте осторожны, чтобы не остановить что-то, что может нарушить работу критического компонента; лучше оставить его в покое, если вы не знаете, что это такое.</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="62"/>
         <location filename="../mainwindow.cpp" line="319"/>
@@ -132,14 +151,6 @@
         <source>&amp;Disable at boot</source>
         <translation>&amp;Отключить при загрузке</translation>
     </message>
-    <message>
-        <source>%1 total services, %2 currently %3running%4</source>
-        <translation type="vanished">%1 общее количество, %2 в настоящее время %3работает%4</translation>
-    </message>
-    <message>
-        <source>%1 %2enabled%3 at boot, but not running</source>
-        <translation type="vanished">%1 %2включено%3 при загрузке, но не работает</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="286"/>
         <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
